@@ -1,4 +1,4 @@
-# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2018 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -51,6 +51,8 @@ pure_functions = {
 
     # minstore.py
     "_",
+    "_p",
+    "absolute",
 
     # defaultstore.py
     "ImageReference", "Image", "Frame", "Solid", "LiveComposite", "LiveCrop",
@@ -175,6 +177,7 @@ class Control(object):
         self.loop = loop
         self.imagemap = imagemap
 
+
 # Three levels of constness.
 GLOBAL_CONST = 2  # Expressions that are const everywhere.
 LOCAL_CONST = 1  # Expressions that are const with regard to a screen + parameters.
@@ -715,6 +718,7 @@ class CompilerCache(object):
 
         return rv
 
+
 ccache = CompilerCache()
 
 CACHE_FILENAME = "cache/pyanalysis.rpyb"
